@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """Load Test Files"""
 
 
 import os
+from typing import List
 
 from baseblock import EnvIO
 from baseblock import FileIO
@@ -23,7 +26,7 @@ class FileLoaderTestCases(BaseObject):
         """
         BaseObject.__init__(self, __name__)
 
-    def process(self) -> list:
+    def process(self) -> List:
         sw = Stopwatch()
 
         path = os.path.join(os.getcwd(), "resources/regression")
