@@ -1,8 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """ Generate an Index of 'exclude-all-of' Mappings"""
 
 
+from typing import Dict
+from typing import List
+from typing import DefaultDict
+
 from collections import defaultdict
 
 from baseblock import Stopwatch
@@ -13,7 +19,7 @@ class IndexExcludeAllOf(BaseObject):
     """ Generate an Index of 'exclude-all-of' Mappings"""
 
     def __init__(self,
-                 mapping: dict):
+                 mapping: Dict):
         """ Change Log
 
         Created:
@@ -30,7 +36,7 @@ class IndexExcludeAllOf(BaseObject):
         BaseObject.__init__(self, __name__)
         self._mapping = mapping
 
-    def process(self) -> dict:
+    def process(self) -> Dict:
         sw = Stopwatch()
         d = defaultdict(list)
 
