@@ -1,8 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """ Generate an Index of 'include-all-of' Mappings"""
 
 
+from typing import Dict
+
 from collections import defaultdict
 
 from baseblock import Stopwatch
@@ -13,7 +17,7 @@ class IndexIncludeOneOf(BaseObject):
     """ Generate an Index of 'include-all-of' Mappings"""
 
     def __init__(self,
-                 mapping: dict):
+                 mapping: Dict):
         """ Change Log
 
         Created:
@@ -30,7 +34,7 @@ class IndexIncludeOneOf(BaseObject):
         BaseObject.__init__(self, __name__)
         self._mapping = mapping
 
-    def process(self) -> dict:
+    def process(self) -> Dict:
         sw = Stopwatch()
         d = defaultdict(list)
 
